<?php
/**
 * Total Recipe Generator Block
 *
 * @uses Lazy Blocks Framework
 * @package Total_Recipe_Generator_Gt
 * @since 0.1.0
 * @version 0.5.0
 */


if ( function_exists( 'lazyblocks' ) ) :

    $block_preview = 'unselected';
    $general = get_option( 'trg_general' );
    if ( isset ( $general ) && is_array( $general ) ) {
        if ( isset( $general['block_preview'] ) ) {
            $block_preview = $general['block_preview'];
        }
    }

    lazyblocks()->add_block( array(
        'id' => 3738,
        'title' => esc_html__( 'Total Recipe Generator', 'trg_gt' ),
        'icon' => '<svg xmlns="http://www.w3.org/2000/svg" width="24" height="24" viewBox="0 0 24 24"><path d="M11 9H9V2H7v7H5V2H3v7c0 2.12 1.66 3.84 3.75 3.97V22h2.5v-9.03C11.34 12.84 13 11.12 13 9V2h-2v7zm5-3v8h2.5v8H21V2c-2.76 0-5 2.24-5 4z" /></svg>',
        'keywords' => array(),
        'slug' => 'lazyblock/total-recipe-generator-gt',
        'description' => esc_html__( 'Create recipe content with Schema microdata.', 'trg_gt' ),
        'category' => 'design',
        'category_label' => 'design',
        'supports' => array(
            'customClassName' => true,
            'anchor' => true,
            'align' => array(
                0 => 'wide',
                1 => 'full',
                2 => 'left',
                3 => 'center',
                4 => 'right',
            ),
            'html' => false,
            'multiple' => true,
            'inserter' => true,
        ),
        'ghostkit' => array(
            'supports' => array(
                'spacings' => false,
                'display' => false,
                'scrollReveal' => false,
                'frame' => false,
                'customCSS' => false,
            ),
        ),
        'controls' => array(
            'control_b4e85b4a2a' => array(
                'type' => 'text',
                'name' => 'name_txt',
                'default' => '',
                'label' => esc_html__( 'Recipe Title', 'trg_gt' ),
                'help' => esc_html__( 'Leave blank for using the post title. You can hide it from the sidebar controls.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_cb58a74107' => array(
                'type' => 'image',
                'name' => 'img_lib',
                'default' => '',
                'label' => esc_html__( 'Recipe Image', 'trg_gt' ),
                'help' => esc_html__( 'Add a recipe image', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'preview_size' => 'large',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2308a64761' => array(
                'type' => 'classic_editor',
                'name' => 'summary',
                'default' => esc_html__( 'This is a recipe summary text. It can be a small excerpt about what you are going to cook.', 'trg_gt' ),
                'label' => esc_html__( 'Summary', 'trg_gt' ),
                'help' => esc_html__( 'Provide a short summary or description of your recipe', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_6228404547' => array(
                'type' => 'number',
                'name' => 'prep_time',
                'default' => esc_html__( '10', 'trg_gt' ),
                'label' => esc_html__( 'Prep time', 'trg_gt' ),
                'help' => esc_html__( 'Preparation time (in minutes). E.g. 10', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '0',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '10',
                'characters_limit' => '',
            ),
            'control_d5da044762' => array(
                'type' => 'number',
                'name' => 'cook_time',
                'default' => esc_html__( '15', 'trg_gt' ),
                'label' => esc_html__( 'Cook Time', 'trg_gt' ),
                'help' => esc_html__( 'Cook time (in minutes). E.g. 15', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '0',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '15',
                'characters_limit' => '',
            ),
            'control_81bb6241cf' => array(
                'type' => 'number',
                'name' => 'perform_time',
                'default' => esc_html__( '15', 'trg_gt' ),
                'label' => esc_html__( 'Perform Time', 'trg_gt' ),
                'help' => esc_html__( 'Provide perform time (in minutes). E.g. 30. This can be used to show resting time, or the time it takes in performing the recipe method.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '0',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '15',
                'characters_limit' => '',
            ),
            'control_4c6a2b459d' => array(
                'type' => 'number',
                'name' => 'total_time',
                'default' => '',
                'label' => esc_html__( 'Total Time', 'trg_gt' ),
                'help' => esc_html__( 'Optional total recipe time (in minutes) if prep time, cook time and perform time are not provided. E.g. 20. Leave blank for auto calculation from prep time, cook time and perform time.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '0',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_32e86b4382' => array(
                'type' => 'text',
                'name' => 'recipe_yield',
                'default' => '',
                'label' => esc_html__( 'Recipe Yield', 'trg_gt' ),
                'help' => esc_html__( 'Provide a recipe yield. E.g. 1 Pizza, or 1 Bowl Rice.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_38194b48d2' => array(
                'type' => 'text',
                'name' => 'serving_size',
                'default' => '',
                'label' => esc_html__( 'Serving Size', 'trg_gt' ),
                'help' => esc_html__( 'Provide a serving size per container. E.g. 1 Piece(20g), or 100g.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_89baa44849' => array(
                'type' => 'text',
                'name' => 'calories',
                'default' => '',
                'label' => esc_html__( 'Energy (Calories per serving)', 'trg_gt' ),
                'help' => esc_html__( 'Provide approximate calories (without unit) per serving. E.g. 240', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_033bfb4568' => array(
                'type' => 'text',
                'name' => 'total_cost',
                'default' => '',
                'label' => esc_html__( 'Total Cost', 'trg_gt' ),
                'help' => esc_html__( 'Provide total cost of recipe.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_8df9f24fb1' => array(
                'type' => 'text',
                'name' => 'cost_per_serving',
                'default' => '',
                'label' => esc_html__( 'Cost per serving', 'trg_gt' ),
                'help' => esc_html__( 'Provide cost per serving.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_308bc64290' => array(
                'type' => 'repeater',
                'name' => 'cust_meta',
                'default' => '',
                'label' => esc_html__( 'Custom Info Board Meta', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'rows_min' => '',
                'rows_max' => '',
                'rows_label' => 'Meta Item {{#}}',
                'rows_add_button_label' => 'Add New Meta',
                'rows_collapsible' => 'true',
                'rows_collapsed' => 'true',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_870a62451c' => array(
                'type' => 'text',
                'name' => 'title',
                'default' => '',
                'label' => esc_html__( 'Meta Label', 'trg_gt' ),
                'help' => esc_html__( 'The label for custom meta item. E.g. Age Group.', 'trg_gt' ),
                'child_of' => 'control_308bc64290',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_8aabf64ea9' => array(
                'type' => 'text',
                'name' => 'value',
                'default' => '',
                'label' => esc_html__( 'Meta Value', 'trg_gt' ),
                'help' => esc_html__( 'The value for custom meta item. E.g. 30 Yr. to 60 Yr.', 'trg_gt' ),
                'child_of' => 'control_308bc64290',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
                'multiline' => 'true',
            ),
            'control_7099a04888' => array(
                'type' => 'select',
                'name' => 'template',
                'default' => esc_html__( 'recipe', 'trg_gt' ),
                'label' => esc_html__( 'Recipe Template', 'trg_gt' ),
                'help' => esc_html__( 'Select a recipe template', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Standard (1 col)', 'trg_gt' ),
                        'value' => 'recipe',
                    ),
                    array(
                        'label' => esc_html__( 'Ingredients + Method (2 col)', 'trg_gt' ),
                        'value' => 'recipe2',
                    ),
                    array(
                        'label' => esc_html__( 'Method + Ingredients (2 col)', 'trg_gt' ),
                        'value' => 'recipe3',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2b8a0d4751' => array(
                'type' => 'toggle',
                'name' => 'show_title',
                'default' => '',
                'label' => esc_html__( 'Recipe Title', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide recipe title', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'true',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_fd5a0f435e' => array(
                'type' => 'select',
                'name' => 'recipe_title_tag',
                'default' => esc_html__( 'h2', 'trg_gt' ),
                'label' => esc_html__( 'Recipe Title Tag', 'trg_gt' ),
                'help' => esc_html__( 'Select an html tag for the recipe title.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'H1', 'trg_gt' ),
                        'value' => 'h1',
                    ),
                    array(
                        'label' => esc_html__( 'H2', 'trg_gt' ),
                        'value' => 'h2',
                    ),
                    array(
                        'label' => esc_html__( 'H3', 'trg_gt' ),
                        'value' => 'h3',
                    ),
                    array(
                        'label' => esc_html__( 'H4', 'trg_gt' ),
                        'value' => 'h4',
                    ),
                    array(
                        'label' => esc_html__( 'H5', 'trg_gt' ),
                        'value' => 'h5',
                    ),
                    array(
                        'label' => esc_html__( 'P', 'trg_gt' ),
                        'value' => 'p',
                    ),
                    array(
                        'label' => esc_html__( 'span', 'trg_gt' ),
                        'value' => 'span',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
                'checked' => 'true',
            ),
            'control_fcda4d4c95' => array(
                'type' => 'color',
                'name' => 'title_color',
                'default' => '',
                'label' => esc_html__( 'Title Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the recipe title.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''          
            ),
            'control_4b89b74040' => array(
                'type' => 'toggle',
                'name' => 'show_date',
                'default' => '',
                'label' => esc_html__( 'Publish Date', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide recipe publish date', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_0a5b884ded' => array(
                'type' => 'toggle',
                'name' => 'show_author',
                'default' => '',
                'label' => esc_html__( 'Recipe Author', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide recipe author', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_1638004bf2' => array(
                'type' => 'select',
                'name' => 'author_src',
                'default' => esc_html__( 'post_author', 'trg_gt' ),
                'label' => esc_html__( 'Author Source', 'trg_gt' ),
                'help' => esc_html__( 'Select author name source for recipe', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Post Author', 'trg_gt' ),
                        'value' => 'post_author',
                    ),
                    array(
                        'label' => esc_html__( 'Custom Name', 'trg_gt' ),
                        'value' => 'custom',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_d149f04ce4' => array(
                'type' => 'text',
                'name' => 'author_name',
                'default' => '',
                'label' => esc_html__( 'Custom Author name', 'trg_gt' ),
                'help' => esc_html__( 'Provide a custom author name', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_74e8a345fc' => array(
                'type' => 'text',
                'name' => 'author_url',
                'default' => '',
                'label' => esc_html__( 'Author profile URL', 'trg_gt' ),
                'help' => esc_html__( 'The profile URL of recipe Author. Leave blank to use WordPress user URL.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => 'http://yoursite.com/author',
                'characters_limit' => '',
            ),
            'control_d4d8204a84' => array(
                'type' => 'toggle',
                'name' => 'show_image',
                'default' => '',
                'label' => esc_html__( 'Recipe Image', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide recipe image', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'true',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_bbb9dd4527' => array(
                'type' => 'select',
                'name' => 'imgsize',
                'default' => esc_html__( 'full', 'trg_gt' ),
                'label' => esc_html__( 'Image Size', 'trg_gt' ),
                'help' => esc_html__( 'Select an html tag for the recipe title.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Thumbnail (150 x 150)', 'trg_gt' ),
                        'value' => 'thumbnail',
                    ),
                    array(
                        'label' => esc_html__( 'Medium (300 x 300)', 'trg_gt' ),
                        'value' => 'medium',
                    ),
                    array(
                        'label' => esc_html__( 'Large (1024 x 1024)', 'trg_gt' ),
                        'value' => 'large',
                    ),
                    array(
                        'label' => esc_html__( 'Full', 'trg_gt' ),
                        'value' => 'full',
                    ),
                    array(
                        'label' => esc_html__( 'Custom', 'trg_gt' ),
                        'value' => 'custom',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
                'checked' => 'true',
            ),
            'control_981a00485c' => array(
                'type' => 'number',
                'name' => 'imgwidth',
                'default' => '',
                'label' => esc_html__( 'Image Width', 'trg_gt' ),
                'help' => esc_html__( 'Image width in (px), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '10',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_322bec4133' => array(
                'type' => 'number',
                'name' => 'imgheight',
                'default' => '',
                'label' => esc_html__( 'Image Height', 'trg_gt' ),
                'help' => esc_html__( 'Image height in (px), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '10',
                'max' => '9999',
                'step' => '1',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_9689e8452e' => array(
                'type' => 'toggle',
                'name' => 'imgcrop',
                'default' => '',
                'label' => esc_html__( 'Image Crop', 'trg_gt' ),
                'help' => esc_html__( 'Enable hard crop mode.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_0b2af04126' => array(
                'type' => 'number',
                'name' => 'imgquality',
                'default' => '',
                'label' => esc_html__( 'Image Quality', 'trg_gt' ),
                'help' => esc_html__( 'Image quality, ranging 1 to 100.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => '1',
                'max' => '100',
                'step' => '1',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_imgalign' => array(
                'type' => 'select',
                'name' => 'imgalign',
                'default' => esc_html__( 'none', 'trg_gt' ),
                'label' => esc_html__( 'Image Align', 'trg_gt' ),
                'help' => esc_html__( 'Select image alignment', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Default', 'trg_gt' ),
                        'value' => 'none',
                    ),
                    array(
                        'label' => esc_html__( 'Left', 'trg_gt' ),
                        'value' => 'left',
                    ),
                    array(
                        'label' => esc_html__( 'Right', 'trg_gt' ),
                        'value' => 'right',
                    ),
                    array(
                        'label' => esc_html__( 'Center', 'trg_gt' ),
                        'value' => 'center',
                    ),
                    array(
                        'label' => esc_html__( 'Wide', 'trg_gt' ),
                        'value' => 'wide',
                    ),
                    array(
                        'label' => esc_html__( 'Full', 'trg_gt' ),
                        'value' => 'full',
                    )
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
                'checked' => 'true',
            ),
            'control_d2ab7b4aac' => array(
                'type' => 'toggle',
                'name' => 'show_summary',
                'default' => '',
                'label' => esc_html__( 'Recipe Summary', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide recipe summary', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'true',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_a26bd14a68' => array(
                'type' => 'color',
                'name' => 'summary_color',
                'default' => '',
                'label' => esc_html__( 'Summary Text Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the recipe summary text.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_3058f94531' => array(
                'type' => 'color',
                'name' => 'ib_label_color',
                'default' => '',
                'label' => esc_html__( 'Info Board Label Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the info board labels.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_5339ca4bb0' => array(
                'type' => 'color',
                'name' => 'ib_value_color',
                'default' => '',
                'label' => esc_html__( 'Highlights Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the info board highlights.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_c6e9dc4d91' => array(
                'type' => 'color',
                'name' => 'rm_labels',
                'default' => '',
                'label' => esc_html__( 'Meta Labels Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the labels of recipe meta.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_8e585149ad' => array(
                'type' => 'color',
                'name' => 'tags_bg',
                'default' => '',
                'label' => esc_html__( 'Tag links background', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the meta tag links.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_f31a4047dd' => array(
                'type' => 'color',
                'name' => 'tags_bg_hover',
                'default' => '',
                'label' => esc_html__( 'Tag links background hover', 'trg_gt' ),
                'help' => esc_html__( 'Choose a hover color for the tag links background.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_470a8b48a9' => array(
                'type' => 'color',
                'name' => 'tags_color',
                'default' => '',
                'label' => esc_html__( 'Tag links Color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the meta tag links text.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_dc28d949cb' => array(
                'type' => 'color',
                'name' => 'tags_color_hover',
                'default' => '',
                'label' => esc_html__( 'Tag links hover color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a hover color for the meta tag links text.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_ing_icon' => array(
                'type' => 'text',
                'name' => 'ing_icon',
                'default' => '',
                'label' => esc_html__( 'Ingredients icon class', 'trg_gt' ),
                'help' => esc_html__( 'Provide a class name for the ingredients icon. E.g. fa-solid fa-bowl-rice', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_f5a8134558' => array(
                'type' => 'color',
                'name' => 'ing_icon_color',
                'default' => '',
                'label' => esc_html__( 'Ingredients icon color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the ingredients icon.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_f85b254369' => array(
                'type' => 'color',
                'name' => 'ing_h_color',
                'default' => '',
                'label' => esc_html__( 'Ingredients heading color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the ingredients heading.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_0deb5f460d' => array(
                'type' => 'color',
                'name' => 'ing_sub_h_color',
                'default' => '',
                'label' => esc_html__( 'Ingredients subheading color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the ingredients group subheading.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),

            'control_ing_list_icon' => array(
                'type' => 'text',
                'name' => 'ing_list_icon',
                'default' => '',
                'label' => esc_html__( 'Ingredients list icon class', 'trg_gt' ),
                'help' => esc_html__( 'Provide a class name for the ingredients list icon. E.g. fa-solid fa-check', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => ''
            ),

            'control_3028d94b2c' => array(
                'type' => 'color',
                'name' => 'list_icon_color',
                'default' => '',
                'label' => esc_html__( 'Ingredients list icon color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the ingredients list icon.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_method_icon' => array(
                'type' => 'text',
                'name' => 'method_icon',
                'default' => '',
                'label' => esc_html__( 'Method icon class', 'trg_gt' ),
                'help' => esc_html__( 'Provide a class name for the Method icon. E.g. fa-solid fa-spoon', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_89cb7f4b1c' => array(
                'type' => 'color',
                'name' => 'method_icon_color',
                'default' => '',
                'label' => esc_html__( 'Method icon color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the method heading icon.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_e89a0a4a15' => array(
                'type' => 'color',
                'name' => 'method_h_color',
                'default' => '',
                'label' => esc_html__( 'Method heading color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the method heading.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_8d79e04b3a' => array(
                'type' => 'color',
                'name' => 'method_sub_h_color',
                'default' => '',
                'label' => esc_html__( 'Method subheading color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the method group subheading.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_17f98f4a14' => array(
                'type' => 'color',
                'name' => 'count_color',
                'default' => '',
                'label' => esc_html__( 'Method count color', 'trg_gt' ),
                'help' => esc_html__( 'Choose a color for the method count numbers.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'alpha' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => ''
            ),
            'control_5a398e48f2' => array(
                'type' => 'select',
                'name' => 'recipe_cuisine',
                'default' => esc_html__( 'American', 'trg_gt' ),
                'label' => esc_html__( 'Recipe Cuisine', 'trg_gt' ),
                'help' => esc_html__( 'Select recipe cuisine from above list or use custom field below.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'American', 'trg_gt' ),
                        'value' => 'American',
                    ),
                    array(
                        'label' => esc_html__( 'Chinese', 'trg_gt' ),
                        'value' => 'Chinese',
                    ),
                    array(
                        'label' => esc_html__( 'French', 'trg_gt' ),
                        'value' => 'French',
                    ),
                    array(
                        'label' => esc_html__( 'Indian', 'trg_gt' ),
                        'value' => 'Indian',
                    ),
                    array(
                        'label' => esc_html__( 'Italian', 'trg_gt' ),
                        'value' => 'Italian',
                    ),
                    array(
                        'label' => esc_html__( 'Japanese', 'trg_gt' ),
                        'value' => 'Japanese',
                    ),
                    array(
                        'label' => esc_html__( 'Mediterranean', 'trg_gt' ),
                        'value' => 'Mediterranean',
                    ),
                    array(
                        'label' => esc_html__( 'Mexican', 'trg_gt' ),
                        'value' => 'Mexican',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_5499c748b4' => array(
                'type' => 'text',
                'name' => 'recipe_cuisine_other',
                'default' => '',
                'label' => esc_html__( 'Other recipe cuisine', 'trg_gt' ),
                'help' => esc_html__( 'Provide comma separated cuisines if not in the above list. E.g. Rajasthani, Gujarati.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_849bbc4326' => array(
                'type' => 'select',
                'name' => 'recipe_category',
                'default' => esc_html__( 'Appetizer', 'trg_gt' ),
                'label' => esc_html__( 'Course', 'trg_gt' ),
                'help' => esc_html__( 'Select recipe course/categories from above list or use custom field below.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Appetizer', 'trg_gt' ),
                        'value' => 'Appetizer',
                    ),
                    array(
                        'label' => esc_html__( 'Breakfast', 'trg_gt' ),
                        'value' => 'Breakfast',
                    ),
                    array(
                        'label' => esc_html__( 'Dessert', 'trg_gt' ),
                        'value' => 'Dessert',
                    ),
                    array(
                        'label' => esc_html__( 'Drinks', 'trg_gt' ),
                        'value' => 'Drinks',
                    ),
                    array(
                        'label' => esc_html__( 'Main Course', 'trg_gt' ),
                        'value' => 'Main Course',
                    ),
                    array(
                        'label' => esc_html__( 'Salad', 'trg_gt' ),
                        'value' => 'Salad',
                    ),
                    array(
                        'label' => esc_html__( 'Snack', 'trg_gt' ),
                        'value' => 'Snack',
                    ),
                    array(
                        'label' => esc_html__( 'Soup', 'trg_gt' ),
                        'value' => 'Soup',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_e75a52454b' => array(
                'type' => 'text',
                'name' => 'recipe_category_other',
                'default' => '',
                'label' => esc_html__( 'Other recipe course', 'trg_gt' ),
                'help' => esc_html__( 'Provide comma separated categories if not in the above list. E.g. Lunch, Starter.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_31dbea4f18' => array(
                'type' => 'text',
                'name' => 'recipe_keywords',
                'default' => '',
                'label' => esc_html__( 'Recipe Keywords', 'trg_gt' ),
                'help' => esc_html__( 'Provide comma separated keywords relevant to your recipe. E.g. fast food, quick meal, vegetarian. These values will be used for Schema only.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_42f8914959' => array(
                'type' => 'text',
                'name' => 'cooking_method',
                'default' => '',
                'label' => esc_html__( 'Cooking Method', 'trg_gt' ),
                'help' => esc_html__( 'Provide a cooking method. E.g. Roasting, Baking.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ba6b3848b4' => array(
                'type' => 'select',
                'name' => 'suitable_for_diet',
                'default' => esc_html__( 'VegetarianDiet', 'trg_gt' ),
                'label' => esc_html__( 'Suitable for Diet', 'trg_gt' ),
                'help' => esc_html__( 'Select diet for which this recipe is suitable. Remove selection using "ctrl + select" if not applicable.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Diabetic', 'trg_gt' ),
                        'value' => 'DiabeticDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Gluten Free', 'trg_gt' ),
                        'value' => 'GlutenFreeDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Halal', 'trg_gt' ),
                        'value' => 'HalalDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Hindu', 'trg_gt' ),
                        'value' => 'HinduDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Kosher', 'trg_gt' ),
                        'value' => 'KosherDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Low Calorie', 'trg_gt' ),
                        'value' => 'LowCalorieDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Low Fat', 'trg_gt' ),
                        'value' => 'LowFatDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Low Lactose', 'trg_gt' ),
                        'value' => 'LowLactoseDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Low Salt', 'trg_gt' ),
                        'value' => 'LowSaltDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Vegan', 'trg_gt' ),
                        'value' => 'VeganDiet',
                    ),
                    array(
                        'label' => esc_html__( 'Vegetarian', 'trg_gt' ),
                        'value' => 'VegetarianDiet',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'true',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ac29bd4f44' => array(
                'type' => 'text',
                'name' => 'suitable_for_diet_other',
                'default' => '',
                'label' => esc_html__( 'Other Suitable for Diet', 'trg_gt' ),
                'help' => esc_html__( 'Provide comma separated values for other suitable for diet. E.g. Organic, Jain.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ae78a14d76' => array(
                'type' => 'toggle',
                'name' => 'show_tags',
                'default' => '',
                'label' => esc_html__( 'Show Tags', 'trg_gt' ),
                'help' => esc_html__( 'Enabling this option will show post tags. You can add tags in the "Tags" panel of post edit screen.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_db4b3b4331' => array(
                'type' => 'repeater',
                'name' => 'cust_attr',
                'default' => '',
                'label' => esc_html__( 'Custom Recipe Attributes', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'rows_min' => '',
                'rows_max' => '',
                'rows_label' => 'Attribute {{#}}',
                'rows_add_button_label' => 'Add Attribute',
                'rows_collapsible' => 'true',
                'rows_collapsed' => 'true',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2d4a7e478e' => array(
                'type' => 'text',
                'name' => 'title',
                'default' => '',
                'label' => esc_html__( 'Attribute Label', 'trg_gt' ),
                'help' => esc_html__( 'The label for custom recipe attribute. E.g. Season', 'trg_gt' ),
                'child_of' => 'control_db4b3b4331',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_08babc4d87' => array(
                'type' => 'text',
                'name' => 'value',
                'default' => '',
                'label' => esc_html__( 'Attribute Values', 'trg_gt' ),
                'help' => esc_html__( 'Attribute values, separated by comma. E.g. Winter, January', 'trg_gt' ),
                'child_of' => 'control_db4b3b4331',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_c06ae54cbe' => array(
                'type' => 'text',
                'name' => 'ing_heading',
                'default' => esc_html__( 'Ingredients', 'trg_gt' ),
                'label' => esc_html__( 'Ingredients Heading', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_1bb8bd4073' => array(
                'type' => 'repeater',
                'name' => 'ingredients',
                'default' => '',
                'label' => esc_html__( 'Recipe Ingredients', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'rows_min' => '',
                'rows_max' => '',
                'rows_label' => 'Ingredients Group {{#}}',
                'rows_add_button_label' => 'Add Ingredients',
                'rows_collapsible' => 'true',
                'rows_collapsed' => 'true',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_c1bb4543ae' => array(
                'type' => 'text',
                'name' => 'method_heading',
                'default' => esc_html__( 'Method', 'trg_gt' ),
                'label' => esc_html__( 'Recipe Method Heading', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_afa91149b0' => array(
                'type' => 'text',
                'name' => 'title',
                'default' => esc_html__( 'For the Burger', 'trg_gt' ),
                'label' => esc_html__( 'Ingredients group title', 'trg_gt' ),
                'help' => esc_html__( 'Provide optional group title if you want to separate ingredients in groups.', 'trg_gt' ),
                'child_of' => 'control_1bb8bd4073',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_80fa9e40a8' => array(
                'type' => 'rich_text',
                'name' => 'list',
                'default' => '',
                'label' => esc_html__( 'Ingredients List', 'trg_gt' ),
                'help' => '',
                'child_of' => 'control_1bb8bd4073',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'multiline' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_81d9664e97' => array(
                'type' => 'toggle',
                'name' => 'enable_numbering',
                'default' => '',
                'label' => esc_html__( 'Auto Numbering', 'trg_gt' ),
                'help' => esc_html__( 'Enable auto numbering on method steps.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'true',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_f388544b8c' => array(
                'type' => 'toggle',
                'name' => 'reset_count',
                'default' => '',
                'label' => esc_html__( 'Reset Numbering', 'trg_gt' ),
                'help' => esc_html__( 'Reset numbering for each method group.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_85b857448d' => array(
                'type' => 'toggle',
                'name' => 'show_nutrition',
                'default' => '',
                'label' => esc_html__( 'Nutrition Facts', 'trg_gt' ),
                'help' => esc_html__( 'Show/hide nutrition facts table.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'true',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_bb8bc34f16' => array(
                'type' => 'toggle',
                'name' => 'show_nutrition_only',
                'default' => '',
                'label' => esc_html__( 'Show Nutrition Facts only', 'trg_gt' ),
                'help' => esc_html__( 'Enable this option to show only Nutrition Facts Table. No recipe post.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_14a8be4c5e' => array(
                'type' => 'repeater',
                'name' => 'methods',
                'default' => '',
                'label' => esc_html__( 'Recipe Method', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'rows_min' => '',
                'rows_max' => '',
                'rows_label' => 'Method Step {{#}}',
                'rows_add_button_label' => 'Add Method Step',
                'rows_collapsible' => 'true',
                'rows_collapsed' => 'true',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_18bb38435d' => array(
                'type' => 'text',
                'name' => 'method_title',
                'default' => esc_html__( 'Preparing the Salad', 'trg_gt' ),
                'label' => esc_html__( 'Method Group Title', 'trg_gt' ),
                'help' => esc_html__( 'Provide a title for the group of steps. E.g. Initial preparation', 'trg_gt' ),
                'child_of' => 'control_14a8be4c5e',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_5c8a0f4428' => array(
                'type' => 'classic_editor',
                'name' => 'method_content',
                'default' => '',
                'label' => esc_html__( 'Method Instruction', 'trg_gt' ),
                'help' => esc_html__( 'Provide detailed method instruction. Use one step per field.', 'trg_gt' ),
                'child_of' => 'control_14a8be4c5e',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_b58ae9439e' => array(
                'type' => 'select',
                'name' => 'display_style',
                'default' => esc_html__( 'std', 'trg_gt' ),
                'label' => esc_html__( 'Nutrition table style', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Standard', 'trg_gt' ),
                        'value' => 'std',
                    ),
                    array(
                        'label' => esc_html__( 'Classic', 'trg_gt' ),
                        'value' => 'classic',
                    ),
                    array(
                        'label' => esc_html__( 'Classic Tabular', 'trg_gt' ),
                        'value' => 'classic tabular',
                    ),
                    array(
                        'label' => esc_html__( 'Flat', 'trg_gt' ),
                        'value' => 'flat',
                    ),
                    array(
                        'label' => esc_html__( 'Flat Striped', 'trg_gt' ),
                        'value' => 'flat striped',
                    ),
                    array(
                        'label' => esc_html__( 'Lined', 'trg_gt' ),
                        'value' => 'lined',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_17fb314d82' => array(
                'type' => 'toggle',
                'name' => 'show_dv',
                'default' => '',
                'label' => esc_html__( 'Show Standard Daily Values', 'trg_gt' ),
                'help' => esc_html__( 'Enabling this option will show standard Daily Values in the chart.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_06f9664eb1' => array(
                'type' => 'classic_editor',
                'name' => 'other_notes',
                'default' => esc_html__( 'This is an extra note from author. This can be any tip, suggestion or fact related to the recipe.', 'trg_gt' ),
                'label' => esc_html__( 'Other Notes', 'trg_gt' ),
                'help' => esc_html__( 'Optional notes for the recipe.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_448ac74788' => array(
                'type' => 'number',
                'name' => 'serving_per_cont',
                'default' => '',
                'label' => esc_html__( 'Serving Per Container', 'trg_gt' ),
                'help' => esc_html__( 'Provide serving per container. E.g. 30', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_4b2aa64ce7' => array(
                'type' => 'number',
                'name' => 'total_fat',
                'default' => '',
                'label' => esc_html__( 'Total Fat', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Total Fat (g), without unit. Standard daily value is 78 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_190b0f4964' => array(
                'type' => 'number',
                'name' => 'saturated_fat',
                'default' => '',
                'label' => esc_html__( 'Saturated Fat', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Saturated Fat (g), without unit. Standard daily value is 20 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_96ba584486' => array(
                'type' => 'number',
                'name' => 'trans_fat',
                'default' => '',
                'label' => esc_html__( 'Trans Fat', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Trans Fat (g), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_6b88ce4f6e' => array(
                'type' => 'number',
                'name' => 'polyunsat_fat',
                'default' => '',
                'label' => esc_html__( 'Polyunsaturated Fat', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Polyunsaturated Fat (g), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_d9281e4811' => array(
                'type' => 'number',
                'name' => 'monounsat_fat',
                'default' => '',
                'label' => esc_html__( 'Monounsaturated Fat', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Monounsaturated Fat (g), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_9e49354336' => array(
                'type' => 'number',
                'name' => 'cholesterol',
                'default' => '',
                'label' => esc_html__( 'Cholesterol', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Cholesterol (mg), without unit. Standard daily value is 300 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_dc18cc4045' => array(
                'type' => 'number',
                'name' => 'sodium',
                'default' => '',
                'label' => esc_html__( 'Sodium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Sodium (mg), without unit. Standard daily value is 2300 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_1aca9449f2' => array(
                'type' => 'number',
                'name' => 'carbohydrate',
                'default' => '',
                'label' => esc_html__( 'Total Carbohydrate', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Total Carbohydrate (g), without unit. Standard daily value is 275 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_65793742d6' => array(
                'type' => 'number',
                'name' => 'fiber',
                'default' => '',
                'label' => esc_html__( 'Dietary Fiber', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Dietary Fiber (g), without unit. Standard daily value is 28 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_9109bc4bf0' => array(
                'type' => 'number',
                'name' => 'sugar',
                'default' => '',
                'label' => esc_html__( 'Total Sugars', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Total Sugars (g), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_1ed8ca4b1a' => array(
                'type' => 'number',
                'name' => 'added_sugar',
                'default' => '',
                'label' => esc_html__( 'Added Sugars', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Added Sugars (g), without unit. Standard daily value is 50 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_cb5a2044fd' => array(
                'type' => 'number',
                'name' => 'sugar_alcohal',
                'default' => '',
                'label' => esc_html__( 'Sugar Alcohal', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Sugar Alcohal (g), without unit.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_5838f1419f' => array(
                'type' => 'number',
                'name' => 'protein',
                'default' => '',
                'label' => esc_html__( 'Protein', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Protein (g), without unit. Standard daily value is 50 g', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_8e18f74da6' => array(
                'type' => 'number',
                'name' => 'vitamin_d',
                'default' => '',
                'label' => esc_html__( 'Vitamin D (Cholecalciferol)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin D (Cholecalciferol) (mcg), without unit. Standard daily value is 20 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_f2d9c04a70' => array(
                'type' => 'number',
                'name' => 'calcium',
                'default' => '',
                'label' => esc_html__( 'Calcium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Calcium (mg), without unit. Standard daily value is 1300 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_a3f8084a6b' => array(
                'type' => 'number',
                'name' => 'iron',
                'default' => '',
                'label' => esc_html__( 'Iron', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Iron (mg), without unit. Standard daily value is 18 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_fa793c4f5b' => array(
                'type' => 'number',
                'name' => 'potassium',
                'default' => '',
                'label' => esc_html__( 'Potassium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Potassium (mg), without unit. Standard daily value is 4700 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_f588004361' => array(
                'type' => 'number',
                'name' => 'vitamin_a',
                'default' => '',
                'label' => esc_html__( 'Vitamin A', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin A (International Units), without unit. Standard daily value is 900 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_0caaf941e0' => array(
                'type' => 'number',
                'name' => 'vitamin_c',
                'default' => '',
                'label' => esc_html__( 'Vitamin C (Ascorbic Acid)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin C (Ascorbic Acid) (mg), without unit. Standard daily value is 90 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_c909074741' => array(
                'type' => 'number',
                'name' => 'vitamin_e',
                'default' => '',
                'label' => esc_html__( 'Vitamin E (Tocopherol)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin E (Tocopherol) (mg), without unit. Standard daily value is 15 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_785bc94712' => array(
                'type' => 'number',
                'name' => 'vitamin_k',
                'default' => '',
                'label' => esc_html__( 'Vitamin K', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin K (mcg), without unit. Standard daily value is 120 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_14785b407b' => array(
                'type' => 'number',
                'name' => 'vitamin_b1',
                'default' => '',
                'label' => esc_html__( 'Vitamin B1 (Thiamin)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B1 (Thiamin) (mg), without unit. Standard daily value is 1.2 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_7bf8c349fa' => array(
                'type' => 'number',
                'name' => 'vitamin_b2',
                'default' => '',
                'label' => esc_html__( 'Vitamin B2 (Riboflavin)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B2 (Riboflavin) (mg), without unit. Standard daily value is 1.3 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_d039ac4a30' => array(
                'type' => 'number',
                'name' => 'vitamin_b3',
                'default' => '',
                'label' => esc_html__( 'Vitamin B3 (Niacin)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B3 (Niacin) (mg), without unit. Standard daily value is 16 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_bf38c74146' => array(
                'type' => 'number',
                'name' => 'vitamin_b6',
                'default' => '',
                'label' => esc_html__( 'Vitamin B6 (Pyridoxine)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B6 (Pyridoxine) (mg), without unit. Standard daily value is 1.7 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_7c49674520' => array(
                'type' => 'number',
                'name' => 'folate',
                'default' => '',
                'label' => esc_html__( 'Folate', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Folate (mcg), without unit. Standard daily value is 400 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_217bb34f6c' => array(
                'type' => 'number',
                'name' => 'vitamin_b12',
                'default' => '',
                'label' => esc_html__( 'Vitamin B12 (Cobalamine)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B12 (Cobalamine) (mcg), without unit. Standard daily value is 2.4 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_3518a1467a' => array(
                'type' => 'number',
                'name' => 'biotin',
                'default' => '',
                'label' => esc_html__( 'Biotin', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Biotin (mcg), without unit. Standard daily value is 30 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2be8cb4fc1' => array(
                'type' => 'number',
                'name' => 'choline',
                'default' => '',
                'label' => esc_html__( 'Choline', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Choline (mg), without unit. Standard daily value is 550 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_951b1b42c7' => array(
                'type' => 'number',
                'name' => 'vitamin_b5',
                'default' => '',
                'label' => esc_html__( 'Vitamin B5 (Pantothenic acid)', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Vitamin B5 (Pantothenic acid) (mg), without unit. Standard daily value is 5 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_f4aaae499d' => array(
                'type' => 'number',
                'name' => 'phosphorus',
                'default' => '',
                'label' => esc_html__( 'Phosphorus', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Phosphorus (mg), without unit. Standard daily value is 1250 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_55080549d7' => array(
                'type' => 'number',
                'name' => 'iodine',
                'default' => '',
                'label' => esc_html__( 'Iodine', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Iodine (mcg), without unit. Standard daily value is 150 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_77b8d142b5' => array(
                'type' => 'number',
                'name' => 'magnesium',
                'default' => '',
                'label' => esc_html__( 'Magnesium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Magnesium (mg), without unit. Standard daily value is 420 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_9ed9c04bd1' => array(
                'type' => 'number',
                'name' => 'zinc',
                'default' => '',
                'label' => esc_html__( 'Zinc', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Zinc (mg), without unit. Standard daily value is 11 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_4a3bb3432c' => array(
                'type' => 'number',
                'name' => 'selenium',
                'default' => '',
                'label' => esc_html__( 'Selenium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Selenium (mcg), without unit. Standard daily value is 55 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_44e8434905' => array(
                'type' => 'number',
                'name' => 'copper',
                'default' => '',
                'label' => esc_html__( 'Copper', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Copper (mg), without unit. Standard daily value is 0.9 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2178e1471f' => array(
                'type' => 'number',
                'name' => 'manganese',
                'default' => '',
                'label' => esc_html__( 'Manganese', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Manganese (mg), without unit. Standard daily value is 2.3 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_cc0b9f4b63' => array(
                'type' => 'number',
                'name' => 'chromium',
                'default' => '',
                'label' => esc_html__( 'Chromium', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Chromium (mcg), without unit. Standard daily value is 35 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_6b8a474cce' => array(
                'type' => 'number',
                'name' => 'molybdenum',
                'default' => '',
                'label' => esc_html__( 'Molybdenum', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Molybdenum (mcg), without unit. Standard daily value is 45 mcg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_8f69fa4a0a' => array(
                'type' => 'number',
                'name' => 'chloride',
                'default' => '',
                'label' => esc_html__( 'Chloride', 'trg_gt' ),
                'help' => esc_html__( 'The amount of Chloride (mg), without unit. Standard daily value is 2300 mg', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_27f8ae4863' => array(
                'type' => 'repeater',
                'name' => 'custom_nutrients',
                'default' => '',
                'label' => esc_html__( 'Additional Nutrients', 'trg_gt' ),
                'help' => '',
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'rows_min' => '',
                'rows_max' => '',
                'rows_label' => 'Nutrient {{#}}',
                'rows_add_button_label' => 'Add Nutrient',
                'rows_collapsible' => 'true',
                'rows_collapsed' => 'true',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_958a9349c8' => array(
                'type' => 'textarea',
                'name' => 'extra_notes',
                'default' => esc_html__( '* The % Daily Value (DV) tells you how much a nutrient in a serving of food contributes to a daily diet. 2,000 calories a day is used for general nutrition advice.', 'trg_gt' ),
                'label' => esc_html__( 'Extra Notes', 'trg_gt' ),
                'help' => esc_html__( 'Provide extra notes for the Nutrition table. This will be displayed at the end of table.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'content',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_1c58a04f6e' => array(
                'type' => 'text',
                'name' => 'name',
                'default' => '',
                'label' => esc_html__( 'Nutrient Name', 'trg_gt' ),
                'help' => esc_html__( 'Provide a nutrient name. E.g. Power Protein', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_9599eb48e6' => array(
                'type' => 'text',
                'name' => 'unit',
                'default' => '',
                'label' => esc_html__( 'Nutrient Quantity Unit', 'trg_gt' ),
                'help' => esc_html__( 'Provide a nutrient unit. E.g. mg', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_4678624b05' => array(
                'type' => 'number',
                'name' => 'amt',
                'default' => '',
                'label' => esc_html__( 'Amount Per Serving', 'trg_gt' ),
                'help' => esc_html__( 'Provide amount per serving (without unit). E.g. 20', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'min' => 0,
                'max' => '',
                'step' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_013b624ee9' => array(
                'type' => 'text',
                'name' => 'sv',
                'default' => '',
                'label' => esc_html__( 'Standard Daily Value', 'trg_gt' ),
                'help' => esc_html__( 'Provide standard daily value of Nutrient (without unit). E.g. 200', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ebaaed41ba' => array(
                'type' => 'select',
                'name' => 'level',
                'default' => '',
                'label' => esc_html__( 'Nutrient Indent Level', 'trg_gt' ),
                'help' => esc_html__( 'Select indent level for the Nutrient entry in table.', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Level 0', 'trg_gt' ),
                        'value' => '0',
                    ),
                    array(
                        'label' => esc_html__( 'Level 1', 'trg_gt' ),
                        'value' => '1',
                    ),
                    array(
                        'label' => esc_html__( 'Level 2', 'trg_gt' ),
                        'value' => '2',
                    ),
                    array(
                        'label' => esc_html__( 'Level 3', 'trg_gt' ),
                        'value' => '3',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2caa1740cb' => array(
                'type' => 'select',
                'name' => 'text_style',
                'default' => '',
                'label' => esc_html__( 'Nutrient text style', 'trg_gt' ),
                'help' => esc_html__( 'Select text style for the nutrient entry.', 'trg_gt' ),
                'child_of' => 'control_27f8ae4863',
                'placement' => 'content',
                'width' => '50',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'Normal', 'trg_gt' ),
                        'value' => 'normal',
                    ),
                    array(
                        'label' => esc_html__( 'Bold', 'trg_gt' ),
                        'value' => 'bold',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_a87ad5435b' => array(
                'type' => 'toggle',
                'name' => 'json_ld',
                'default' => '',
                'label' => esc_html__( 'JSON LD Schema', 'trg_gt' ),
                'help' => esc_html__( 'Enabling this option will add json ld schema data in recipe container.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_3f985e404e' => array(
                'type' => 'toggle',
                'name' => 'website_schema',
                'default' => '',
                'label' => esc_html__( 'Website Schema', 'trg_gt' ),
                'help' => esc_html__( 'Add website schema. This should be off if your theme already includes website schema, or you are using an SEO plugin like Yoast for website schema.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'checked' => 'false',
                'alongside_text' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_2c1aff4680' => array(
                'type' => 'select',
                'name' => 'rating_src',
                'default' => '',
                'label' => esc_html__( 'Rating Schema', 'trg_gt' ),
                'help' => esc_html__( 'Rating schema value can be included from visitor rating of WP Review or Rate my Post plugin. Choose which one you are using.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'choices' => array(
                    array(
                        'label' => esc_html__( 'WP Review Plugin', 'trg_gt' ),
                        'value' => 'mts',
                    ),
                    array(
                        'label' => esc_html__( 'Rate My Post Plugin', 'trg_gt' ),
                        'value' => 'rmp',
                    ),
                ),
                'allow_null' => 'false',
                'multiple' => 'false',
                'output_format' => '',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_e628324fed' => array(
                'type' => 'text',
                'name' => 'vid_name',
                'default' => '',
                'label' => esc_html__( 'Video Name (Schema only)', 'trg_gt' ),
                'help' => esc_html__( 'Provide a name for the Recipe video to be used in Schema.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_e1a9534bc9' => array(
                'type' => 'text',
                'name' => 'vid_url',
                'default' => '',
                'label' => esc_html__( 'Video URL', 'trg_gt' ),
                'help' => esc_html__( 'Provide a URL of recipe video. E.g. https://www.youtube.com/watch?v=RTleJqGUJKE', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_39396d43c7' => array(
                'type' => 'image',
                'name' => 'vid_thumb_url',
                'default' => '',
                'label' => esc_html__( 'Video Thumbnail', 'trg_gt' ),
                'help' => esc_html__( 'Add a video thumbnail image.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'preview_size' => 'medium',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_652b2341b1' => array(
                'type' => 'textarea',
                'name' => 'vid_description',
                'default' => '',
                'label' => esc_html__( 'Video Description', 'trg_gt' ),
                'help' => esc_html__( 'Provide video description to be used in schema.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_d9c94b4ebd' => array(
                'type' => 'date_time',
                'name' => 'vid_date',
                'default' => '',
                'label' => esc_html__( 'Video Upload Date', 'trg_gt' ),
                'help' => esc_html__( 'Provide date of uploading the video.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'date_time_picker' => 'date',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_4f2a894df4' => array(
                'type' => 'text',
                'name' => 'vid_duration',
                'default' => '',
                'label' => esc_html__( 'Video Duration', 'trg_gt' ),
                'help' => esc_html__( 'Provide video duration in ISO 8601 format. E.g. PT8M33S (for 8min 33 sec duration)', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ad_spot_1' => array(
                'type' => 'textarea',
                'name' => 'ad_spot_1',
                'default' => '',
                'label' => esc_html__( 'Advertisement Spot 1', 'trg_gt' ),
                'help' => esc_html__( 'Place your advertisement code here.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ad_spot_2' => array(
                'type' => 'textarea',
                'name' => 'ad_spot_2',
                'default' => '',
                'label' => esc_html__( 'Advertisement Spot 2', 'trg_gt' ),
                'help' => esc_html__( 'Place your advertisement code here.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
            'control_ad_spot_3' => array(
                'type' => 'textarea',
                'name' => 'ad_spot_3',
                'default' => '',
                'label' => esc_html__( 'Advertisement Spot 3', 'trg_gt' ),
                'help' => esc_html__( 'Place your advertisement code here.', 'trg_gt' ),
                'child_of' => '',
                'placement' => 'inspector',
                'width' => '100',
                'hide_if_not_selected' => 'false',
                'save_in_meta' => 'false',
                'save_in_meta_name' => '',
                'required' => 'false',
                'placeholder' => '',
                'characters_limit' => '',
            ),
        ),
        'code' => array(
            'output_method' => 'template',
            'editor_html' => '',
            'editor_callback' => '',
            'editor_css' => '',
            'frontend_html' => '',
            'frontend_callback' => '',
            'frontend_css' => '',
            'show_preview' => $block_preview,
            'single_output' => true,
        ),
        'condition' => array(),
    ) );
    
endif;